[java-idp-plugin-duo] branch main updated: Cleanup flow test

Phil Smart philip.smart at jisc.ac.uk
Mon Jan 8 17:46:52 UTC 2024


This is an automated email from the git hooks/post-receive script.

philsmart pushed a commit to branch main
in repository java-idp-plugin-duo.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-plugin-duo.git;a=commit;h=8c2c98e96cf7a989704fb3f7ffba21d4c5ee2f43

The following commit(s) were added to refs/heads/main by this push:
     new 8c2c98e9 Cleanup flow test
8c2c98e9 is described below

commit 8c2c98e96cf7a989704fb3f7ffba21d4c5ee2f43
Author: Phil Smart <philip.smart at jisc.ac.uk>
AuthorDate: Mon Jan 8 17:46:49 2024 +0000

    Cleanup flow test
---
 .../net/shibboleth/idp/plugin/authn/duo/impl/DuoAuthnFlowTest.java | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/idp-duo-impl/src/test/java/net/shibboleth/idp/plugin/authn/duo/impl/DuoAuthnFlowTest.java b/idp-duo-impl/src/test/java/net/shibboleth/idp/plugin/authn/duo/impl/DuoAuthnFlowTest.java
index 97f24079..aac1b41a 100644
--- a/idp-duo-impl/src/test/java/net/shibboleth/idp/plugin/authn/duo/impl/DuoAuthnFlowTest.java
+++ b/idp-duo-impl/src/test/java/net/shibboleth/idp/plugin/authn/duo/impl/DuoAuthnFlowTest.java
@@ -249,12 +249,12 @@ public class DuoAuthnFlowTest extends AbstractAuthnXmlFlowExecutionTests {
     }
     
     /** 
      * Test the Duo flow up to the external authorization request when using the passwordless flow.
      * 
      * @throws IOException on error
      */
     @Test
-    public void testDuoAuthnFlowToAuthorizationRequestForPasswordless() throws IOException {
+    public void testDuoAuthnFlowToPasswordlessViewForPasswordlessIntegration() throws IOException {
         
         
         // Requires mock server to handle Admin API calls
@@ -289,8 +289,7 @@ public class DuoAuthnFlowTest extends AbstractAuthnXmlFlowExecutionTests {
        
         final ProfileRequestContext context = buildProfileRequestContext(false,true);
         // Add passwordless context to init passwordless flow
-        final DuoPasswordlessContext passwordlessContext = new DuoPasswordlessContext();
-        context.ensureSubcontext(AuthenticationContext.class).addSubcontext(passwordlessContext);
+        context.ensureSubcontext(AuthenticationContext.class).addSubcontext(new DuoPasswordlessContext());
         // Add a username into the request for the passwordless flow to use
         mockRequest.addParameter("j_username", "jdoe");
         
@@ -249,12 +249,12 @@ public class DuoAuthnFlowTest extends AbstractAuthnXmlFlowExecutionTests {
     
     /** 
-     * Test the Duo flow up to the external authorization request when using the passwordless flow.
+     * Test the Duo flow up to the passwordless view when using a passwordless integration.
      * 
      * @throws IOException on error

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list